@@ -1,7 +1,7 @@
 # ABSTRACT: turn WGS84 coordinates into three word addresses and vice-versa using what3words.com HTTPS API
 
 package Geo::What3Words;
-$Geo::What3Words::VERSION = '3.0.1';
+$Geo::What3Words::VERSION = '3.0.2';
 use strict;
 use warnings;
 use Cpanel::JSON::XS;
@@ -12,7 +12,8 @@ use HTTP::Tiny;
 use Net::Ping;
 use Net::Ping::External;
 use Ref::Util qw( is_hashref is_coderef );
-use URI::XS;
+use URI;
+# DO NOT TRY TO USE URI::XS IT JUST LEADS TO PROBLEMS
 
 my $JSONXS = Cpanel::JSON::XS->new->allow_nonref(1);
 
@@ -44,7 +45,7 @@ sub ping {
 
     ## http://example.com/some/path => example.com
     ## also works with IP addresses
-    my $host = URI::XS->new($self->{api_endpoint})->host;
+    my $host = URI->new($self->{api_endpoint})->host;
 
     $self->_log("pinging $host...");
 
@@ -144,10 +145,8 @@ sub _query_remote_api {
         delete $rh_fields->{$key} if (!defined($rh_fields->{$key}));
     }
 
-    my $uri = URI::XS->new($self->{api_endpoint} . $method_name);
-    $uri->query($rh_fields);
-    # if we use URI then need query_form, not query
-    # $uri->query_form($rh_fields);
+    my $uri = URI->new($self->{api_endpoint} . $method_name);
+    $uri->query_form($rh_fields);
     my $url = $uri->as_string;
 
     $self->_log("GET $url");
@@ -195,7 +194,7 @@ Geo::What3Words - turn WGS84 coordinates into three word addresses and vice-vers
 
 =head1 VERSION
 
-version 3.0.1
+version 3.0.2
 
 =head1 SYNOPSIS
 
